"""
ODL Parsing Example (using metadata from an ASTER HDF file)

This module demonstrates the use of the ODL parser to extract
information from the hdf dataset.  The parser returns a
dictionary of dictionaries, where subdictionaries correspond
to objects (the dictionary values being their attributes) or
groups thereof (values then being additional dictionaries)
"""

# This is a demonstration of the use of the pyhdf module to
# analyze data from the aster satellite.  Use is made of the
# function parse_odl, which parses the ODL dialect used in the
# datasets.

# import necessary modules
from scikits.rsformats import parse_odl


# This ODL file comes from an ASTER AST05 Surface Emissivity Level 2 data
# product. Consult this URL for more information:
#    http://asterweb.jpl.nasa.gov/content/03_data/01_Data_Products/release_surface_emissivity_product.htm
f = open('productmetadata.0.odl')
odl = f.read()
f.close()

# load the parse_odl function
Dict = parse_odl(odl)
print "Type of the dictionary made from the ODL data: ", type( Dict )
# output: <class 'pyhdf.odl_parser.Bunch'>


# Relevant data can now be conveniently accessed like a dictionary
print "A value of one of Dict's subdictionaries: ", \
      Dict['ASTERGDSGENERICMETADATA']['GROUPTYPE']
# output: 'MASTERGROUP'

# ... or by attribute access
print "Another value: %s" % (Dict.ASTERGDSGENERICMETADATA.CALIBRATIONINFORMATION,)

